languageeditor — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- editors »

# languageeditor

class `camelot.view.controls.editors.languageeditor.` `LanguageEditor`(parent=None, languages=[], field_name='language', **kwargs)

  A ComboBox that shows a list of languages, the editor takes as its value the ISO code of the language

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- editors »

Comments
blog comments powered by Disqus